@@ -30,7 +30,7 @@ class Options:
     def __init__(self, cfg: config.Config):
         self.config = cfg
         self.encoding_registry: encoding.Registry = encoding.Registry()
-        self.matcher_path: str = ""
+        self.run_paths: list[str] = []
         self.packages_paths: list[str] = []
         self.sources: dict[str, source.Base] = {}
 
@@ -175,32 +175,16 @@ def execute(opts: Options) -> bool:
 
     pkg_reader = package.PackageReader(opts.encoding_registry)
     pkgs = pkg_reader.read_packages(opts.packages_paths)
-    matcher = run.read(opts.matcher_path)
-    pkgs_to_apply = find_packages(matcher.packages, pkgs)
-    repositories = []
+    repositories: list[source.Repository] = []
     for s in opts.sources.values():
         repositories += s.list_repositories()
 
     log.info("Repositories returned by sources", count=len(repositories))
-    gitc = git.Git(
-        matcher.branch(opts.config.git.branch_prefix),
-        opts.config.git.clone_options,
-        opts.config.git.data_dir,
-        opts.config.git.user_name,
-        opts.config.git.user_email,
-    )
-    runner = RepoRun(gitc, opts)
     success = True
-    for repo in repositories:
-        if matcher.match(repo) is False:
-            log.debug("Repository does not match", repository=str(repo))
-            continue
-
-        log.info("Matched repository", repository=str(repo))
-        try:
-            runner.execute(matcher, pkgs_to_apply, repo)
-        except Exception:
-            log.exception("Apply failed", repository=str(repo))
+    for run_path in opts.run_paths:
+        run_ = run.read(run_path)
+        run_success = execute_run(run_, pkgs, repositories, opts)
+        if run_success is False:
             success = False
 
     if success is False:
@@ -216,16 +200,50 @@ def execute_local(
     structlog.configure(
         wrapper_class=structlog.make_filtering_bound_logger(log_level),
     )
+    if len(opts.run_paths) == 0:
+        log.warning("No path to a run file supplied")
+        return
 
     pkg_reader = package.PackageReader(opts.encoding_registry)
     pkgs = pkg_reader.read_packages(opts.packages_paths)
-    matcher = run.read(opts.matcher_path)
+    matcher = run.read(opts.run_paths[0])
     pkgs_to_apply = find_packages(matcher.packages, pkgs)
     repo = Local(repo_source, repo_project, repo_name)
     tpl_mapping: dict[str, str] = create_template_mapping(repo)
     apply_actions(pkgs_to_apply, repo, matcher, tpl_mapping, directory)
 
 
+def execute_run(
+    run_: run.Run,
+    pkgs: list[package.Package],
+    repos: list[source.Repository],
+    opts: Options,
+) -> bool:
+    pkgs_to_apply = find_packages(run_.packages, pkgs)
+    gitc = git.Git(
+        run_.branch(opts.config.git.branch_prefix),
+        opts.config.git.clone_options,
+        opts.config.git.data_dir,
+        opts.config.git.user_name,
+        opts.config.git.user_email,
+    )
+    runner = RepoRun(gitc, opts)
+    success = True
+    for repo in repos:
+        if run_.match(repo) is False:
+            log.debug("Repository does not match", repository=str(repo), run=run_.name)
+            continue
+
+        log.info("Matched repository", repository=str(repo), run=run_.name)
+        try:
+            runner.execute(run_, pkgs_to_apply, repo)
+        except Exception:
+            log.exception("Run failed", repository=str(repo), run=run_.name)
+            success = False
+
+    return success
+
+
 def options_from_config(path: str) -> Options:
     cfg = config.read_config_from_file(path)
     return config_to_options(cfg)
