@@ -1,20 +1,23 @@
 import datetime
-from typing import Any, Union
+import fnmatch
+import io
+from typing import Any, TextIO, Union
 
 import github
 import github.PullRequest
 import github.Repository
 import structlog
 
-from .source import Base, PullRequest, Repository
+from ..log import SECRET_MASKER
+from .source import Base, PullRequest, Repository, add_credentials_to_url
 
 log = structlog.get_logger(source="github")
 
 
 class GithubRepository(Repository):
-    def __init__(self, repo: github.Repository.Repository):
+    def __init__(self, access_token: str, repo: github.Repository.Repository):
+        self.access_token = access_token
         self.repo = repo
-        self._clone_url = repo.clone_url
         self._name = repo.name
         self._project = repo.owner.login
 
@@ -24,7 +27,9 @@ class GithubRepository(Repository):
 
     @property
     def clone_url(self):
-        return self.repo.clone_url
+        return add_credentials_to_url(
+            url=self.repo.clone_url, password=self.access_token
+        )
 
     def create_pull_request(self, branch: str, pr: PullRequest):
         log.debug(
@@ -46,16 +51,27 @@ class GithubRepository(Repository):
 
         return None
 
-    def has_file(self, path: str) -> bool:
+    def get_file(self, path: str) -> TextIO:
         try:
-            self.repo.get_contents(path=path, ref=self.base_branch)
-        except github.UnknownObjectException as e:
-            if e.status == 404:
-                return False
-            else:
-                raise e
+            file = self.repo.get_contents(path=path, ref=self.base_branch)
+        except github.UnknownObjectException:
+            raise FileNotFoundError("file does not exist in repository")
 
-        return True
+        if isinstance(file, list):
+            if len(file) != 1:
+                raise FileNotFoundError("github returned more than one file")
+
+            file = file[0]
+
+        return io.StringIO(file.decoded_content.decode("utf-8"))
+
+    def has_file(self, path: str) -> bool:
+        tree = self.repo.get_git_tree(self.base_branch, True)
+        for entry in tree.tree:
+            if fnmatch.fnmatch(entry.path, path):
+                return True
+
+        return False
 
     def has_successful_pr_build(self, pr: github.PullRequest.PullRequest) -> bool:
         log.debug("Checking PR builds", repo=str(self))
@@ -109,13 +125,16 @@ class GithubRepository(Repository):
 
 class Github(Base):
     def __init__(self, access_token: str, base_url: str):
+        self.access_token = access_token
         self.client = github.Github(login_or_token=access_token, base_url=base_url)
 
+        SECRET_MASKER.add_secret(access_token)
+
     def list_repositories(self) -> list[Repository]:
         log.debug("start fetching repositories")
         repos: list[Repository] = []
         for gh_repo in self.client.get_user().get_repos():
-            repos.append(GithubRepository(gh_repo))
+            repos.append(GithubRepository(self.access_token, gh_repo))
 
         log.debug("finished fetching repositories")
         return repos
