@@ -1,5 +1,6 @@
 import datetime
-from typing import Any, Union
+import urllib.parse
+from typing import Any, TextIO, Union
 
 
 class PullRequest:
@@ -116,6 +117,9 @@ class Repository:
             "class does not implement Repository.has_open_pull_request()"
         )
 
+    def get_file(self, path: str) -> TextIO:
+        raise NotImplementedError("class does not implement Repository.has_file()")
+
     def has_file(self, path: str) -> bool:
         """
         Checks if a file exists in a repository.
@@ -239,3 +243,13 @@ class Base:
         raise NotImplementedError(
             "class does not implement SourceLister.list_repositories()"
         )
+
+
+def add_credentials_to_url(url: str, password: str, username: str = "") -> str:
+    parsed = urllib.parse.urlparse(url)
+    if username == "":
+        credentials = password
+    else:
+        credentials = f"{username}:{password}"
+
+    return parsed._replace(netloc=f"{credentials}@{parsed.netloc}").geturl()
